/*
Object class use to represent the list of keywords.
Each level is represented by its own ArrayList of Keyword objects.

Developed by Soham Hanuman Singh, sngsoh004@myuct.ac.za
*/

import java.io.File;
import java.io.FileNotFoundException;
import java.util.ArrayList;
import java.util.Scanner;

public class KeywordList 
{
    public ArrayList<Keyword> knowledge;
    public ArrayList<Keyword> comprehension;
    public ArrayList<Keyword> application;
    public ArrayList<Keyword> analysis;         //ArrayLists to represent each level in the taxonomy
    public ArrayList<Keyword> synthesis;
    public ArrayList<Keyword> evaluation;
    
    public KeywordList()
    {
        knowledge = new ArrayList();
        comprehension = new ArrayList();
        application = new ArrayList();
        analysis = new ArrayList();
        synthesis = new ArrayList();
        evaluation = new ArrayList();
    }
    
    public KeywordList(String filename) throws FileNotFoundException //constructor which takes the text file containing keywords as a parameter and reads these keywords into the corresponding ArrayList
    {
        knowledge = new ArrayList();
        comprehension = new ArrayList();
        application = new ArrayList();
        analysis = new ArrayList();
        synthesis = new ArrayList();
        evaluation = new ArrayList();
        
        Scanner sc = new Scanner(new File("keywords.txt"));
        String currentLevel = "";
        
        while(sc.hasNextLine())
        {
            String temp = sc.nextLine();
            if (temp.startsWith("LEVEL:")) //New level identified
            {
                currentLevel = temp.substring(temp.indexOf(":")+1);
            }
            
            else //add the current token as a new keyword to the current level's ArrayList
            {
                if (currentLevel.equalsIgnoreCase("Knowledge")) knowledge.add(new Keyword(temp));
                
                else if (currentLevel.equalsIgnoreCase("Comprehension")) comprehension.add(new Keyword(temp));
                
                else if (currentLevel.equalsIgnoreCase("Application")) application.add(new Keyword(temp));
                
                else if (currentLevel.equalsIgnoreCase("Analysis")) analysis.add(new Keyword(temp));
                
                else if (currentLevel.equalsIgnoreCase("Synthesis")) synthesis.add(new Keyword(temp));
                
                else if (currentLevel.equalsIgnoreCase("Evaluation")) evaluation.add(new Keyword(temp));
            }
        }
    }
    
    boolean hasKeyword(String word, String level) //checks if a specific level contains a specific keyword
    {
        if (level.equalsIgnoreCase("Knowledge"))
        {
            for (int i = 0; i < knowledge.size(); i++) {
                if (knowledge.get(i).word.equalsIgnoreCase(word)) return true;
            }
        }
        
        else if (level.equalsIgnoreCase("Comprehension"))
        {
            for (int i = 0; i < comprehension.size(); i++) {
                if (comprehension.get(i).word.equalsIgnoreCase(word)) return true;
            }
        }
        
        else if (level.equalsIgnoreCase("Application"))
        {
            for (int i = 0; i < application.size(); i++) {
                if (application.get(i).word.equalsIgnoreCase(word)) return true;
            }
        }
        
        else if (level.equalsIgnoreCase("Analysis"))
        {
            for (int i = 0; i < analysis.size(); i++) {
                if (analysis.get(i).word.equalsIgnoreCase(word)) return true;
            }
        }
        
        else if (level.equalsIgnoreCase("Synthesis"))
        {
            for (int i = 0; i < synthesis.size(); i++) {
                if (synthesis.get(i).word.equalsIgnoreCase(word)) return true;
            }
        }
        
        else if (level.equalsIgnoreCase("Evaluation"))
        {
            for (int i = 0; i < evaluation.size(); i++) {
                if (evaluation.get(i).word.equalsIgnoreCase(word)) return true;
            }
        }
        return false;
    }
    
    double getWeight(String word, String level) //returns the corresponding weight value for a specific keyword in a specific level
    {
        if (level.equalsIgnoreCase("Knowledge"))
        {
            for (int i = 0; i < knowledge.size(); i++) {
                if (knowledge.get(i).word.equalsIgnoreCase(word)) return knowledge.get(i).weight;
            }
        }
        
        else if (level.equalsIgnoreCase("Comprehension"))
        {
            for (int i = 0; i < comprehension.size(); i++) {
                if (comprehension.get(i).word.equalsIgnoreCase(word)) return comprehension.get(i).weight;
            }
        }
        
        else if (level.equalsIgnoreCase("Application"))
        {
            for (int i = 0; i < application.size(); i++) {
                if (application.get(i).word.equalsIgnoreCase(word)) return application.get(i).weight;
            }
        }
        
        else if (level.equalsIgnoreCase("Analysis"))
        {
            for (int i = 0; i < analysis.size(); i++) {
                if (analysis.get(i).word.equalsIgnoreCase(word)) return analysis.get(i).weight;
            }
        }
        
        else if (level.equalsIgnoreCase("Synthesis"))
        {
            for (int i = 0; i < synthesis.size(); i++) {
                if (synthesis.get(i).word.equalsIgnoreCase(word)) return synthesis.get(i).weight;
            }
        }
        
        else if (level.equalsIgnoreCase("Evaluation"))
        {
            for (int i = 0; i < evaluation.size(); i++) {
                if (evaluation.get(i).word.equalsIgnoreCase(word)) return evaluation.get(i).weight;
            }
        }
        return 0;
    }
    
    void printKeywords() //method to display the stored keywords for each level
    {
        System.out.println("Knowledge:");
        for (int i = 0; i < knowledge.size(); i++) {
            System.out.println(knowledge.get(i).word);
        }

        System.out.println("-------------");

        System.out.println("Comprehension:");
        for (int i = 0; i < comprehension.size(); i++) {
            System.out.println(comprehension.get(i).word);
        }

        System.out.println("-------------");

        System.out.println("Application:");
        for (int i = 0; i < application.size(); i++) {
            System.out.println(application.get(i).word);
        }

        System.out.println("-------------");

        System.out.println("Analysis:");
        for (int i = 0; i < analysis.size(); i++) {
            System.out.println(analysis.get(i).word);
        }

        System.out.println("-------------");

        System.out.println("Synthesis:");
        for (int i = 0; i < synthesis.size(); i++) {
            System.out.println(synthesis.get(i).word);
        }

        System.out.println("-------------");

        System.out.println("Evaluation:");
        for (int i = 0; i < evaluation.size(); i++) {
            System.out.println(evaluation.get(i).word);
        }

        System.out.println("-------------");
    }
}
